MethodChannelBlinkCardFlutter class

An implementation of BlinkCardFlutterPlatform that uses method channels.

MethodChannelCaptureFlutter exposes the appropriate native BlinkCard module as a Flutter/Dart module, based on the detected platform: Android or iOS.

The method channel contains the methods performScan and performDirectApiScan which enable the BlinkCard scanning process, with the default UX properties, and with static images.

The method channel also contains the loadSdk and method for loading the BlinkCard SDK before the scanning process to reduce the initilization waiting time

The method channel contains the unloadSdk method for unloading the BlinkCard that can be used for remove the resources connected with the SDK.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadSdk({required BlinkCardSdkSettings blinkCardSdkSettings}) Future<void>
The loadSdk platform channel method creates or retrieves the instance of the BlinkCard SDK.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performDirectApiScan({required BlinkCardSdkSettings blinkCardSdkSettings, required BlinkCardSessionSettings blinkCardSessionSettings, required String firstSideImage, String? secondSideImage}) Future<BlinkCardScanningResult?>
The performDirectApiScan platform channel method launches the BlinkCard scanning process intended for information extraction from static images. It takes the following parameters: BlinkCardSdkSettings, BlinkCardSessionSettings, firstImage String in the Base64 format and the optional secondImage String in the Base64 format.
override
performScan({required BlinkCardSdkSettings? blinkCardSdkSettings, required BlinkCardSessionSettings blinkCardSessionSettings, ScanningUxSettings? scanningUxSettings}) Future<BlinkCardScanningResult?>
The performScan platform channel method launches the BlinkCard scanning process with the default UX properties. It takes the following parameters: BlinkCardSdkSettings, and the optional BlinkCardSessionSettings and ScanningUxSettings classes.
override
toString() String
A string representation of this object.
inherited
unloadSdk({bool deleteCachedResources = false}) Future<void>
The unloadSdk platform channel method terminates the BlinkCard SDK and releases all associated resources.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited