BlinkCardFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BlinkCardFlutterPlatform
Implementers

Constructors

BlinkCardFlutterPlatform()
Constructs a BlinkCardFlutterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadSdk({required BlinkCardSdkSettings blinkCardSdkSettings}) Future<void>
Returns the loadSdk method from the MethodChannelBlinkCardFlutter. It takes the following parameter: BlinkCardSdkSettings See MethodChannelBlinkCardFlutter for more detailed information.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performDirectApiScan({required BlinkCardSdkSettings blinkCardSdkSettings, required BlinkCardSessionSettings blinkCardSessionSettings, required String firstSideImage, String? secondSideImage}) Future<BlinkCardScanningResult?>
Returns the performDirectApiScan method from the MethodChannelBlinkCardFlutter. It takes the following parameters: BlinkCardSdkSettings, SessionSettings, firstSideImage String in the Base64 format and the optional secondSideImage String in the Base64 format. See MethodChannelBlinkCardFlutter for more detailed information.
performScan({required BlinkCardSdkSettings blinkCardSdkSettings, required BlinkCardSessionSettings blinkCardSessionSettings, ScanningUxSettings? scanningUxSettings}) Future<BlinkCardScanningResult?>
Returns the performScan method from the MethodChannelBlinkCardFlutter. It takes the following parameters: BlinkCardSdkSettings, and the optional SessionSettings and ScanningUxSettings. See MethodChannelBlinkCardFlutter for more detailed information.
toString() String
A string representation of this object.
inherited
unloadSdk({bool deleteCachedResources = false}) Future<void>
Returns the unloadSdk method from the MethodChannelBlinkCardFlutter. It takes the following parameter: BlinkCardSdkSettings See MethodChannelBlinkCardFlutter for more detailed information.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BlinkCardFlutterPlatform
The default instance of BlinkCardFlutterPlatform to use.
getter/setter pair