stepTimeTimeoutInterval property

int stepTimeTimeoutInterval
getter/setter pair

Duration in milliseconds before scanning step times out and is cancelled.

If less than zero, scanning will not time out. Default: to 15000 (15 seconds)

Implementation

int stepTimeTimeoutInterval;