CroppedImageSettings class final

Represents the image cropping settings.

This class controls how card images are cropped, including the resolution, extension of the cropping area, and whether the cropped image should be returned in the results.

Annotations
  • @JsonSerializable.new()

Constructors

CroppedImageSettings({int dotsPerInch = 250, double extensionFactor = 0.0, bool returnCardImage = false})
Represents the image cropping settings.
CroppedImageSettings.fromJson(Map<String, dynamic> json)
factory

Properties

dotsPerInch int
The DPI value for the cropped image.
getter/setter pair
extensionFactor double
The extension factor for the cropped card image. Value must be in range [0.0, 1.0].
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
returnCardImage bool
Indicates whether the cropped card image should be returned.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited