ExtractionSettings class final

Controls which fields and images should be extracted from the payment card.

Disabling extraction of unused fields can improve recognition performance or reduce memory usage.

Annotations
  • @JsonSerializable.new()

Constructors

ExtractionSettings({bool extractIban = true, bool extractExpiryDate = true, bool extractCardholderName = true, bool extractCvv = true, bool extractInvalidCardNumber = false})
Controls which fields and images should be extracted from the payment card.
ExtractionSettings.fromJson(Map<String, dynamic> json)
factory

Properties

extractCardholderName bool
Whether to extract the cardholder name.
getter/setter pair
extractCvv bool
Whether to extract the CVV (Card Verification Value) security code.
getter/setter pair
extractExpiryDate bool
Whether to extract the card expiry date. Default: true
getter/setter pair
extractIban bool
Whether to extract the IBAN (International Bank Account Number). Default: true
getter/setter pair
extractInvalidCardNumber bool
Indicates whether card numbers that fail checksum validation should be accepted.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited