ExtractionSettings constructor

ExtractionSettings({
  1. bool extractIban = true,
  2. bool extractExpiryDate = true,
  3. bool extractCardholderName = true,
  4. bool extractCvv = true,
  5. bool extractInvalidCardNumber = false,
})

Controls which fields and images should be extracted from the payment card.

Disabling extraction of unused fields can improve recognition performance or reduce memory usage.

Implementation

ExtractionSettings({
  this.extractIban = true,
  this.extractExpiryDate = true,
  this.extractCardholderName = true,
  this.extractCvv = true,
  this.extractInvalidCardNumber = false,
});