extractInvalidCardNumber property

bool extractInvalidCardNumber
getter/setter pair

Indicates whether card numbers that fail checksum validation should be accepted.

Card numbers are validated using the Luhn algorithm.

A value of false (default) means only card numbers that pass the checksum validation will be accepted. A value of true means card numbers that fail checksum validation will still be accepted.

This may be useful for testing purposes or when processing damaged/worn cards. The cardNumberValid field in the result will still indicate whether the checksum passed.

Default: false

Implementation

bool extractInvalidCardNumber;