ScanningSettings class final

Represents the configurable settings for scanning a card.

This class defines various parameters and policies related to the scanning process, including image quality handling, data extraction, anonymization, and liveness detection, along with options for frame processing and image extraction.

Annotations
  • @JsonSerializable.new()

Constructors

ScanningSettings({bool skipImagesWithBlur = true, DetectionLevel tiltDetectionLevel = DetectionLevel.mid, double inputImageMargin = 0.02, LivenessSettings? livenessSettings, AnonymizationSettings? anonymizationSettings, CroppedImageSettings? croppedImageSettings, ExtractionSettings? extractionSettings})
ScanningSettings.fromJson(Map<String, dynamic> json)
factory

Properties

anonymizationSettings AnonymizationSettings
Represents the configurable settings for data anonymization.
getter/setter pair
croppedImageSettings CroppedImageSettings
Configures the image cropping settings during scanning process.
getter/setter pair
extractionSettings ExtractionSettings
Controls which fields and images should be extracted from the card.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputImageMargin double
Defines the minimum required margin (in percentage) between the edge of the input image and the card. Default value is 0.02 (also recommended value).
getter/setter pair
livenessSettings LivenessSettings
Represents the configurable settings for liveness detection.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipImagesWithBlur bool
Indicates whether to reject frames if blur is detected on the card image.
getter/setter pair
tiltDetectionLevel DetectionLevel
The level of allowed detected tilt of the card in the image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited