extractionSettings property

ExtractionSettings extractionSettings
getter/setter pair

Controls which fields and images should be extracted from the card.

Disabling extraction of unused fields can improve recognition performance or reduce memory usage.

Implementation

ExtractionSettings extractionSettings;