inputImageMargin property

double inputImageMargin
getter/setter pair

Defines the minimum required margin (in percentage) between the edge of the input image and the card. Default value is 0.02 (also recommended value).

The setting is applicable only when using images from Video source.

Default: 0.02.

Implementation

double inputImageMargin;