types library

Classes

BlinkCardSingleSideScanningResult
Represents the result of scanning a single side of the card.
CardAccountResult
Represents the account information of a single account on a card.
CardLivenessCheckResult
Structure representing the result of liveness checks for a card.
CardNumberAnonymizationSettings
Holds the settings which control card number anonymization.
CroppedImageResult
DateResult<StringType>
Represents the result of the date extraction.

Enums

AnonymizationMode
Represents level of anonymization performed on the scanning result.
CameraPosition
Represents camera positions used for card information extraction.
CheckResult
Result of a single check performed during the document verification process.
DetectionLevel
Represents the different levels of detection sensitivity.
StrictnessLevel
Defines the strictness level used by various models to control detection sensitivity.