cardImage property
The cropped image of the scanned card, or null if image capture failed.
Implementation
final CroppedImageResult? cardImage;
The cropped image of the scanned card, or null if image capture failed.
final CroppedImageResult? cardImage;