cardNumberValid property
Indicates whether the scanned card number is valid according to the Luhn algorithm.
Implementation
final bool cardNumberValid;
Indicates whether the scanned card number is valid according to the Luhn algorithm.
final bool cardNumberValid;