CardLivenessCheckResult class final

Structure representing the result of liveness checks for a card.

Constructors

CardLivenessCheckResult.fromMap(Map<String, dynamic> nativeCardLivenessCheckResult)

Properties

cardHeldInHandCheckResult CheckResult
Result of the liveness check that detects whether a card is being held in human hands.
final
hashCode int
The hash code for this object.
no setterinherited
photocopyCheckResult CheckResult
Result of the liveness check that detects whether the input image is a photocopy of a card.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenCheckResult CheckResult
Result of the liveness check that detects whether the card is displayed on a screen.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited