cardHeldInHandCheckResult property
Result of the liveness check that detects whether a card is being held in human hands.
Implementation
final CheckResult cardHeldInHandCheckResult;
Result of the liveness check that detects whether a card is being held in human hands.
final CheckResult cardHeldInHandCheckResult;