photocopyCheckResult property
Result of the liveness check that detects whether the input image is a photocopy of a card.
Implementation
final CheckResult photocopyCheckResult;
Result of the liveness check that detects whether the input image is a photocopy of a card.
final CheckResult photocopyCheckResult;