screenCheckResult property
Result of the liveness check that detects whether the card is displayed on a screen.
Implementation
final CheckResult screenCheckResult;
Result of the liveness check that detects whether the card is displayed on a screen.
final CheckResult screenCheckResult;