prefixDigitsVisible property
Defines how many digits at the beginning of the card number remain visible after anonymization.
Default: 0
Implementation
int prefixDigitsVisible;
Defines how many digits at the beginning of the card number remain visible after anonymization.
Default: 0
int prefixDigitsVisible;