filledByDomainKnowledge property
Indicates that date does not appear on the document but is filled by our internal domain knowledge.
Implementation
final bool filledByDomainKnowledge;
Indicates that date does not appear on the document but is filled by our internal domain knowledge.
final bool filledByDomainKnowledge;