originalString property
StringType
originalString
final
Original string representation of the date which has been extracted.
Implementation
final StringType originalString;
Original string representation of the date which has been extracted.
final StringType originalString;