blinkcard_settings library
Classes
- AnonymizationSettings
- Holds the settings which control the anonymization of returned data.
- BlinkCardSdkSettings
- Settings for initialization of the BlinkCard SDK.
- BlinkCardSessionSettings
- Represents the configuration settings for a scanning session.
- CroppedImageSettings
- Represents the image cropping settings.
- ExtractionSettings
- Controls which fields and images should be extracted from the payment card.
- LivenessSettings
- Configuration settings for liveness detection during card scanning.
- ScanningSettings
- Represents the configurable settings for scanning a card.
- ScanningUxSettings
- Allows customization of various aspects of the UI/UX used during the scanning process.