BlinkCardSessionSettings class final
Represents the configuration settings for a scanning session.
This class holds the settings related to the input image source and specific scanning configurations that define how the scanning session should behave.
- Annotations
-
- @JsonSerializable.new()
Constructors
- BlinkCardSessionSettings({ScanningSettings? scanningSettings, int stepTimeTimeoutInterval = 15000})
-
BlinkCardSessionSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanningSettings ↔ ScanningSettings
-
The specific scanning settings for the scanning session.
Defines various parameters that control the scanning process.
getter/setter pair
- stepTimeTimeoutInterval ↔ int
-
Duration in milliseconds before scanning step
times out and is cancelled.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited