CroppedImageSettings constructor
CroppedImageSettings({})
Represents the image cropping settings.
This class controls how card images are cropped, including the resolution, extension of the cropping area, and whether the cropped image should be returned in the results.
Implementation
CroppedImageSettings({
this.dotsPerInch = 250,
this.extensionFactor = 0.0,
this.returnCardImage = false,
});