returnCardImage property
Indicates whether the cropped card image should be returned.
Provides the complete card image for record keeping or further processing. Disable to reduce memory usage if image is not needed.
Default: false.
Implementation
bool returnCardImage;