ExtractionSettings constructor
ExtractionSettings({})
Controls which fields and images should be extracted from the payment card.
Disabling extraction of unused fields can improve recognition performance or reduce memory usage.
Implementation
ExtractionSettings({
this.extractIban = true,
this.extractExpiryDate = true,
this.extractCardholderName = true,
this.extractCvv = true,
this.extractInvalidCardNumber = false,
});