anonymizationSettings property
Represents the configurable settings for data anonymization.
This defines various parameters and policies related to the anonymization of sensitive data extracted from the payment cards.
Defaults to no anonymization.
Implementation
AnonymizationSettings anonymizationSettings;