extractionSettings property
Controls which fields and images should be extracted from the card.
Disabling extraction of unused fields can improve recognition performance or reduce memory usage.
Implementation
ExtractionSettings extractionSettings;
Controls which fields and images should be extracted from the card.
Disabling extraction of unused fields can improve recognition performance or reduce memory usage.
ExtractionSettings extractionSettings;