skipImagesWithBlur property
Indicates whether to reject frames if blur is detected on the card image.
When true (default), frames with detected blur are skipped to ensure only high-quality images are processed.
When false, blurred frames are still processed, and the blur status is reported in the ProcessResult.
Default: true.
Implementation
bool skipImagesWithBlur;