ScanningUxSettings class final
Allows customization of various aspects of the UI/UX used during the scanning process.
- Annotations
-
- @JsonSerializable.new()
Constructors
- ScanningUxSettings({bool showIntroductionAlert = true, bool showHelpButton = true, CameraPosition preferredCameraPosition = CameraPosition.back, bool allowHapticFeedback = true})
- Allows customization of various aspects of the UI/UX used during the scanning process.
-
ScanningUxSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allowHapticFeedback ↔ bool
-
When enabled, haptic responses are generated during scanning activities,
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- preferredCameraPosition ↔ CameraPosition
-
The preferred camera position to use when capturing document.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showHelpButton ↔ bool
-
Determines if help button for raising an onboarding sheet will be shown.
getter/setter pair
- showIntroductionAlert ↔ bool
-
Determines if alert will be shown when scanning start.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited