BlinkCardSingleSideScanningResult class final
Represents the result of scanning a single side of the card.
Contains the cropped card image and liveness check results from scanning one side of a card.
Constructors
-
BlinkCardSingleSideScanningResult(Map<
String, dynamic> nativeBlinkCardSingleSideScanningResult)
Properties
- cardImage → CroppedImageResult?
-
The cropped image of the scanned card, or null if image capture failed.
final
- cardLivenessCheckResult → CardLivenessCheckResult
-
The result of the card liveness verification check.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited