CardAccountResult class final
Represents the account information of a single account on a card.
Constructors
-
CardAccountResult(Map<
String, dynamic> nativeCardAccountResult)
Properties
- cardCategory → String?
-
The category of the payment card
(e.g., "PERSONAL", "BUSINESS", "PREPAID").
final
- cardNumber → String
-
The card number as scanned from the card.
final
- cardNumberPrefix → String?
-
The payment card's number prefix.
final
- cardNumberValid → bool
-
Indicates whether the scanned card number is valid according to the Luhn algorithm.
final
- cvv → String?
-
The payment card's security code/value.
final
-
expiryDate
→ DateResult<
String> ? -
The payment card's expiry date.
final
- fundingType → String?
-
The card funding type (e.g., "DEBIT", "CREDIT", "CHARGE CARD").
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuerCountry → String?
-
The name of the card issuer's country.
final
- issuerCountryCode → String?
-
The ISO 3166-1 alpha-3 country code of the card issuer's country (e.g., "USA", "GBR", "HRV").
final
- issuerName → String?
-
The name of the financial institution that issued the payment card.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited