DateResult<StringType> class
final
Represents the result of the date extraction.
Constructors
-
DateResult(Map<
String, dynamic> nativeDateResult)
Properties
- day → int?
-
Day of the month.
final
- filledByDomainKnowledge → bool
-
Indicates that date does not appear on the document
but is filled by our internal domain knowledge.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- month → int?
-
Month of the year.
final
- originalString → StringType
-
Original string representation of the date which has been extracted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successfullyParsed → bool
-
Indicates whether date was successfully parsed.
final
- year → int?
-
Full year.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited