StrictnessLevel enum
Defines the strictness level used by various models to control detection sensitivity.
Higher levels apply stricter validation criteria, improving security and reducing false accepts (FAR), but may increase false rejects (FRR).
Levels are ordered by increasing strictness:
- Disabled turns the check off.
- The first active level has the lowest FRR and highest FAR.
- The last level has the highest FRR and lowest FAR.
Values
- disabled → const StrictnessLevel
- level1 → const StrictnessLevel
- level2 → const StrictnessLevel
- level3 → const StrictnessLevel
- level4 → const StrictnessLevel
- level5 → const StrictnessLevel
- level6 → const StrictnessLevel
- level7 → const StrictnessLevel
- level8 → const StrictnessLevel
- level9 → const StrictnessLevel
- level10 → const StrictnessLevel
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StrictnessLevel> - A constant List of the values in this enum, in order of their declaration.